@@ -3,7 +3,7 @@
 #' @noRd
 foo_gbif <- function(sources, query, limit, start, geometry, has_coords, callopts, opts) {
   if (any(grepl("gbif", sources))) {
-    
+
     opts$hasCoordinate <- has_coords
     if (!is.null(query)) {
       if (class(query) %in% c("ids", "gbifid")) {
@@ -23,8 +23,8 @@ foo_gbif <- function(sources, query, limit, start, geometry, has_coords, callopt
     } else {
       query_use <- NULL
     }
-    
-    if (is.null(query_use) && is.null(geometry)) {
+
+    if (is.null(query_use) && is.null(geometry) && length(opts) == 0) {
       warning(sprintf("No records found in GBIF for %s", query), call. = FALSE)
       emptylist(opts)
     } else {
@@ -43,11 +43,15 @@ foo_gbif <- function(sources, query, limit, start, geometry, has_coords, callopt
       out <- tryCatch(do.call("occ_search", opts), error = function(e) e)
       if (is(out, "simpleError")) {
         warning(sprintf("No records found in GBIF for %s", query), call. = FALSE)
-        list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+        emptylist(opts)
       } else {
         if (class(out) == "character") { emptylist(opts) } else {
           if (class(out$data) == "character") { emptylist(opts) } else {
-            dat <- out$data
+            if (length(out) > 1 && !all(c('meta', 'data') %in% names(out))) {
+              dat <- setDF(rbindlist(lapply(out, "[[", "data"), fill = TRUE, use.names = TRUE))
+            } else {
+              dat <- out$data
+            }
             dat$prov <- rep("gbif", nrow(dat))
             dat$name <- as.character(dat$name)
             cols <- c('name', 'decimalLongitude', 'decimalLatitude', 'issues', 'prov')
@@ -56,7 +60,8 @@ foo_gbif <- function(sources, query, limit, start, geometry, has_coords, callopt
             dat <- stand_latlon(dat)
             dat <- add_latlong_if_missing(dat)
             dat <- stand_dates(dat, "gbif")
-            list(time = time, found = out$meta$count, data = dat, opts = opts)
+            list(time = time, found = out$meta$count,
+                 data = as_data_frame(dat), opts = opts)
           }
         }
       }
@@ -80,7 +85,7 @@ foo_ecoengine <- function(sources, query, limit, page, geometry, has_coords, cal
       opts$bbox <- if (grepl('POLYGON', paste(as.character(geometry), collapse = " "))) {
         paste0(wkt2bbox(geometry), collapse = ",")
       } else {
-        geometry 
+        geometry
       }
     }
     # This could hang things if request is super large.  Will deal with this issue
@@ -95,10 +100,10 @@ foo_ecoengine <- function(sources, query, limit, page, geometry, has_coords, cal
     opts$foptions <- callopts
     out_ee <- tryCatch(do.call(ee_observations2, opts), error = function(e) e)
     if (out_ee$results == 0 || is(out_ee, "simpleError")) {
-      warning(sprintf("No records found in Ecoengine for %s", 
+      warning(sprintf("No records found in Ecoengine for %s",
         if (is.null(query)) paste0(substr(geometry, 1, 20), ' ...') else query
       ), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       out <- out_ee$data
       fac_tors <- sapply(out, is.factor)
@@ -108,10 +113,10 @@ foo_ecoengine <- function(sources, query, limit, page, geometry, has_coords, cal
       names(out)[names(out) == 'scientific_name'] <- "name"
       out <- add_latlong_if_missing(out)
       out <- stand_dates(out, "ecoengine")
-      list(time = time, found = out_ee$results, data = out, opts = opts)
+      list(time = time, found = out_ee$results, data = as_data_frame(out), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
@@ -123,34 +128,34 @@ foo_antweb <- function(sources, query, limit, start, geometry, has_coords, callo
     opts$georeferenced <- has_coords
     # limit <- NULL
     geometry <- NULL
-    
+
     query <- sub("^ +", "", query)
     query <- sub(" +$", "", query)
-    
+
     if (length(strsplit(query, " ")[[1]]) == 2) {
       opts$scientific_name <- query
     } else {
       opts$genus <- query
       opts$scientific_name <- NULL
     }
-    
+
     if (!'limit' %in% names(opts)) opts$limit <- limit
     if (!'offset' %in% names(opts)) opts$offset <- start
     out <- tryCatch(do.call(aw_data2, opts), error = function(e) e)
-    
+
     if (is.null(out) || is(out, "simpleError")) {
       warning(sprintf("No records found in AntWeb for %s", query), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       res <- out$data
       res$prov <- rep("antweb", nrow(res))
       res$name <- query
       res <- stand_latlon(res)
       res <- add_latlong_if_missing(res)
-      list(time = time, found = out$count, data = res, opts = opts)
+      list(time = time, found = out$count, data = as_data_frame(res), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
@@ -174,10 +179,10 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
         bisonfxn <- "bison"
       }
     }
-    
+
     time <- now()
     opts$verbose <- FALSE
-    
+
     if (bisonfxn == "bison") {
       if (!'count' %in% names(opts)) opts$count <- limit
       opts$config <- callopts
@@ -186,7 +191,7 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
       opts$callopts <- callopts
     }
     if (!'start' %in% names(opts)) opts$start <- start
-    
+
     if (!is.null(geometry)) {
       opts$aoi <- if (grepl('POLYGON', paste(as.character(geometry), collapse = " "))) {
         geometry
@@ -197,7 +202,7 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
     out <- tryCatch(do.call(eval(parse(text = bisonfxn)), opts), error = function(e) e)
     if (is.null(out$points) || is(out, "simpleError")) {
       warning(sprintf("No records found in Bison for %s", query), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       dat <- out$points
       dat$prov <- rep("bison", nrow(dat))
@@ -206,14 +211,13 @@ foo_bison <- function(sources, query, limit, start, geometry, callopts, opts) {
       dat <- add_latlong_if_missing(dat)
       dat <- stand_dates(dat, "bison")
       found <- if (bisonfxn == "bison_solr") out$num_found else out$summary$total
-      list(time = time, found = found, data = dat, opts = opts)
+      list(time = time, found = found, data = as_data_frame(dat), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
-
 #' @noRd
 foo_inat <- function(sources, query, limit, page, geometry, has_coords, callopts, opts) {
   if (any(grepl("inat", sources))) {
@@ -236,7 +240,7 @@ foo_inat <- function(sources, query, limit, page, geometry, has_coords, callopts
     out <- tryCatch(do.call("spocc_inat_obs", opts), error = function(e) e)
     if (!is.data.frame(out$data) || is(out, "simpleError")) {
       warning(sprintf("No records found in INAT for %s", query), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       res <- out$data
       res$prov <- rep("inat", nrow(res))
@@ -244,10 +248,10 @@ foo_inat <- function(sources, query, limit, page, geometry, has_coords, callopts
       res <- stand_latlon(res)
       res <- add_latlong_if_missing(res)
       res <- stand_dates(res, "inat")
-      list(time = time, found = out$meta$found, data = res, opts = opts)
+      list(time = time, found = out$meta$found, data = as_data_frame(res), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
@@ -269,19 +273,19 @@ foo_ebird <- function(sources, query, limit, callopts, opts) {
     } else {
       out <- tryCatch(do.call(ebirdgeo, opts[!names(opts) %in% "method"]), error = function(e) e)
     }
-    if (!is.data.frame(out) || is(out, "simpleError")) {
+    if (!is.data.frame(out) || is(out, "simpleError") || NROW(out) == 0) {
       warning(sprintf("No records found in eBird for %s", query), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       out$prov <- rep("ebird", nrow(out))
       names(out)[names(out) == 'sciName'] <- "name"
       out <- stand_latlon(out)
       out <- add_latlong_if_missing(out)
       out <- stand_dates(out, "ebird")
-      list(time = time, found = NULL, data = out, opts = opts)
+      list(time = time, found = NULL, data = as_data_frame(out), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
@@ -299,7 +303,7 @@ foo_vertnet <- function(sources, query, limit, has_coords, callopts, opts) {
     out <- tryCatch(do.call(vertsearch, opts), error = function(e) e)
     if (!is.data.frame(out$data) || is(out, "simpleError")) {
       warning(sprintf("No records found in VertNet for %s", query), call. = FALSE)
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       df <- out$data
       df$prov <- rep("vertnet", NROW(df))
@@ -311,10 +315,12 @@ foo_vertnet <- function(sources, query, limit, has_coords, callopts, opts) {
       df <- add_latlong_if_missing(df)
       df <- stand_dates(df, "vertnet")
       names(df) <- tolower(names(df))
-      list(time = time, found = as.numeric(gsub(">|<", "", out$meta$matching_records)), data = df, opts = opts)
+      list(time = time,
+           found = as.numeric(gsub(">|<", "", out$meta$matching_records)),
+           data = as_data_frame(df), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
 
@@ -322,7 +328,7 @@ foo_vertnet <- function(sources, query, limit, has_coords, callopts, opts) {
 foo_idigbio <- function(sources, query, limit, start, geometry, has_coords, callopts, opts) {
   if (any(grepl("idigbio", sources))) {
     time <- now()
-    
+
     addopts <- list()
     if (!is.null(query)) addopts$rq <- list(scientificname = query)
     if (!is.null(has_coords)) opts$rq$geopoint <- if (has_coords) {
@@ -330,17 +336,17 @@ foo_idigbio <- function(sources, query, limit, start, geometry, has_coords, call
     } else {
       list(type = "missing")
     }
-    
+
     if (!is.null(geometry)) {
       if (grepl('POLYGON', paste(as.character(geometry), collapse = " "))) {
         geometry <- wkt2bbox(geometry)
       }
       addopts$rq <- if (is.numeric(geometry) && length(geometry) == 4) {
         list(geopoint = list(
-          type = "geo_bounding_box", 
+          type = "geo_bounding_box",
           top_left = list(
             lat = geometry[4], lon = geometry[1]
-          ), 
+          ),
           bottom_right = list(
             lat = geometry[2], lon = geometry[3]
           )
@@ -349,21 +355,23 @@ foo_idigbio <- function(sources, query, limit, start, geometry, has_coords, call
         geometry
       }
     }
-    
+
     if ("rq" %in% names(opts)) {
       opts$rq <- c(addopts$rq, opts$rq)
     } else {
       opts$rq <- addopts$rq
     }
-    
+
     if (!"limit" %in% names(opts)) opts$limit <- limit
     if (!'offset' %in% names(opts)) opts$offset <- start
     opts$fields <- "all"
-    
+
+    opts$config <- callopts
+
     out <- tryCatch(do.call(idig_search_records, opts), error = function(e) e)
     if (is(out, "simpleError")) {
       warning(sprintf("No records found in iDigBio for %s", query))
-      list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+      emptylist(opts)
     } else{
       out$prov <- rep("idigbio", nrow(out))
       out <- rename(out, c('scientificname' = 'name'))
@@ -371,9 +379,10 @@ foo_idigbio <- function(sources, query, limit, start, geometry, has_coords, call
       out <- stand_latlon(out)
       out <- add_latlong_if_missing(out)
       out <- stand_dates(out, "idigbio")
-      list(time = time, found = attr(out, "itemCount"), data = out, opts = opts)
+      list(time = time, found = attr(out, "itemCount"),
+           data = as_data_frame(out), opts = opts)
     }
   } else {
-    list(time = NULL, found = NULL, data = data.frame(NULL), opts = opts)
+    emptylist(opts)
   }
 }
